precompute_descendants: Precompute descendant tips for each node

View source: R/utils.R

precompute_descendantsR Documentation

Precompute descendant tips for each node

Description

Called once before randomization loops to avoid recomputing tree structure.

Usage

precompute_descendants(tree)

Arguments

tree

A phylo object

Value

A list where element i contains the tip indices descending from node i


phylospatial documentation built on April 4, 2026, 1:07 a.m.